#!/bin/bash

# Length in minutes of each chapter when DVD without menues is created
CHAPTER_LEN=5

# Start Command with nice ? If not wished then set NICE=""
NICE="nice -n 19"

# Use cut function of vdrsync (yes|no)
USE_CUT=yes

# Use "tcrequant" or plain "requant" command (yes|no)
USE_TCREQUANT=yes

# when script is called out of $PATH then add directory of script to $PATH
# there may be other needed programs in this directory
export PATH=$PATH:$(dirname $0)

logger -s "<$*>"

# debug script execution
set -x

ExecCmd() {
   logger -s "Starting <$NICE $*>"
   $NICE "$@"
}

# Sync Syntax: TempDir Number FileName
if [ "$1" = "SYNC" ]; then
   if [ "$USE_CUT" == "yes" ]; then
      CUTCMD="-cut"
   fi
   ExecCmd vdrsync.pl $CUTCMD -o "$2/VDRSYNC.$3" "$4"

# Requant Syntax: TempDir Number Filename Faktor
elif [ "$1" = "REQUANT" ]; then
   if [ "$USE_TCREQUANT" == "yes" ]; then
      ExecCmd tcrequant -f "$5" -i "$4" -o "$2/VDRSYNC.$3/requant.mpv"
   else
      ExecCmd requant "$5" < "$4" > "$2/VDRSYNC.$3/requant.mpv"
   fi

# Mplex Syntax: TempDir FileName1 FileName2 FileName3
elif [ "$1" = "MPLEX" ]; then
   if [ "$5" != "" ]; then
       ExecCmd mplex -f 8 -vbr -v 1 -o "$2/movie.mpg" "$3" "$4" "$5"
   else
       ExecCmd mplex -f 8 -vbr -v 1 -o "$2/movie.mpg" "$3" "$4"
   fi

# Author Syntax: TempDir or XML-File
elif [ "$1" = "AUTHOR" ]; then
   if [ -d "$2" ]; then
      cd "$2"
      for i in $(seq 0 99) ; do
         if [ -f "VDRSYNC.$i/movie.mpg" ] ; then
            echo "Found: VDRSYNC.$i"
            CS="-c 0"
            for j in $(seq $CHAPTER_LEN $CHAPTER_LEN 300) ; do
               SH=$(($j / 60))
               SM=$(($j % 60))
               CS="$CS,$SH:$SM:0"
   	    done
            ExecCmd dvdauthor -o "$2/DVDAUTHOR" $CS -f "$2/VDRSYNC.$i/movie.mpg"
         else
            break
         fi
      done
      ExecCmd dvdauthor -T -o "$2/DVDAUTHOR"
   else
      ExecCmd dvdauthor -x "$2"
   fi

# MkIso Syntax: TempDir IsoDir JobTitle
elif [ "$1" = "MKISO" ] ; then
   ExecCmd mkisofs -V "${4:0:32}" -dvd-video "$2/DVDAUTHOR" > "$3/$4.iso"

# Burn Syntax: TempDir Device JobTitle
elif [ "$1" = "BURN" ] ; then
   ExecCmd growisofs -use-the-force-luke=tty -dvd-compat -Z "$3" -V "${4:0:32}" -dvd-video "$2/DVDAUTHOR"

# MkIso-Burn Syntax: TempDir Device IsoDir JobTitle FifoPath
elif [ "$1" = "MKISO_BURN" ] ; then
   ExecCmd growisofs -use-the-force-luke=tty -dvd-compat -Z "$3=$6" | mkisofs -V "${5:0:32}" -dvd-video "$2/DVDAUTHOR" | tee "$4/$5.iso" > "$6"

else
   echo "Illegal Parameter <$1>"
fi
